aboutsummaryrefslogtreecommitdiff
path: root/audio/decoders/quicktime.h
diff options
context:
space:
mode:
Diffstat (limited to 'audio/decoders/quicktime.h')
-rw-r--r--audio/decoders/quicktime.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/audio/decoders/quicktime.h b/audio/decoders/quicktime.h
index eb0f791748..9e2e95b705 100644
--- a/audio/decoders/quicktime.h
+++ b/audio/decoders/quicktime.h
@@ -80,16 +80,18 @@ protected:
int8 _audioStreamIndex;
uint _curAudioChunk;
QueuingAudioStream *_audStream;
+
+ void setAudioStreamPos(const Timestamp &where);
};
/**
* Try to load a QuickTime sound file from the given file name and create a RewindableAudioStream
* from that data.
*
* @param filename the filename of the file from which to read the data
* @return a new RewindableAudioStream, or NULL, if an error occurred
*/
-RewindableAudioStream *makeQuickTimeStream(const Common::String &filename);
+SeekableAudioStream *makeQuickTimeStream(const Common::String &filename);
} // End of namespace Audio
@@ -80,16 +80,18 @@ protected:
};
/**
- * Try to load a QuickTime sound file from the given file name and create a RewindableAudioStream
+ * Try to load a QuickTime sound file from the given file name and create a SeekableAudioStream
* from that data.
*
@@ -80,16 +80,18 @@ protected:
*
* @param filename the filename of the file from which to read the data
- * @return a new RewindableAudioStream, or NULL, if an error occurred
+ * @return a new SeekableAudioStream, or NULL, if an error occurred
*/